# ifndef yyNormalization
# define yyNormalization

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Normalization_Exit) ARGS ((void));

extern void Normalization ARGS ((tTree t));

extern void BeginNormalization ARGS ((void));
extern void CloseNormalization ARGS ((void));

# endif
